# Using DISNET towards COVID-19 drug repositioning

This repository is structured as follows:

>```
>disnet_covid_paper
>├── counts
>│	├── count_dbc_path4.tsv 
>│	├── count_dpc_path2.tsv
>│	├── count_drugs_path1.tsv
>│	├── count_drugs_path2.tsv
>│	├── count_drugs_path3.tsv
>│	├── count_drugs_path4.tsv
>│	└── count_drugs_path5.tsv
>├── paths
>│	├── covid_genes.tsv
>│	├── covid_symptoms.tsv
>│	├── diseases_bio_covid.tsv
>│	├── diseases_pheno_covid.tsv
>│	├── genes_dpc.tsv
>│	├── targets_gc.tsv
>│	└── targets_dpc.tsv
>├── results
>│	├── drugs_allpaths.tsv
>│	├── drugs_path1.tsv
>│	├── drugs_path2.tsv
>│	├── drugs_path3.tsv
>│	├── drugs_path4.tsv
>│	└── drugs_path5.tsv
>├── paths-pipeline.svg
>└── README.md
>```

Two important concepts to clarify:

- **dpc**: stands for those diseases phenotypically related to COVID-19, that is, that have common symptoms.

- **dbc**: stands for those diseases biologically related to COVID-19, that is, that have related genes in common.


## counts

Files with different counts along the five paths of information.

- **count_dbc_path4.tsv** 

| disease_id|disease_name|count_genes|
|:-:|:-:|:-:|
|Identifiers of diseases that have biological resemblance with COVID-19 (dbc), i.e. that have genes in common|Names of the diseases|Number of shared genes between diseases (dbc) and COVID-19|

- **count_dpc_path2.tsv** 

|disease_name|count_symptoms|
|:-:|:-:|
|Names of diseases that have phenotypical resemblance with COVID-19 (dpc), i.e. that have symptoms in common|Number of shared symptoms between diseases (dpc) and COVID-19|

- **count_drugs_path1.tsv** 

|drug_id|drug_name|count_symptoms|
|:-:|:-:|:-:|
|Identifiers of drugs potentially repurposable for COVID-19|Names of the drugs|Number of COVID related symptoms to which drugs are indicated for|

- **count_drugs_path2.tsv** 

|drug_id|drug_name|count_dpc|
|:-:|:-:|:-:|
|Identifiers of drugs potentially repurposable for COVID-19|Names of the drugs|Number of diseases (dpc) that are associated to the drugs|

- **count_drugs_path3.tsv**

|drug_id|drug_name|count_targets|
|:-:|:-:|:-:|
|Identifiers of drugs potentially repurposable for COVID-19|Names of the drugs|Number of targets associated to each drug that are related to diseases that have phenotypical resemblance with COVID-19 (dpc)|

- **count_drugs_path4.tsv** 

|drug_id|drug_name|count_dbc|
|:-:|:-:|:-:|
|Identifiers of drugs potentially repurposable for COVID-19|Names of the drugs|Number of diseases (dbc) that are associated to the drugs|

- **count_drugs_path5.tsv**

|drug_id|drug_name|count_targets|
|:-:|:-:|:-:|
|Identifiers of drugs potentially repurposable for COVID-19|Names of the drugs|Number of targets related to COVID-19 genes that are associated to each drug|


## paths

Files with different data obtained in the paths of information.

- **covid_genes.tsv** : genes that are related to COVID-19

|gene_id|gene_symbol|gene_name|
|:-:|:-:|:-:|
|NCBI identifiers of genes|Symbols of the genes|Complete name of the genes|

- **covid_symptoms.tsv** : symptoms that are related to COVID-19

|symptom_cui|symptom_name|source|
|:-:|:-:|:-:|
|UMLS CUIs identifying COVID-19 symptoms|Names of the symptoms|Textual source from which the symptoms have been extracted|

- **diseases_bio_covid.tsv** : (dbc) diseases that have a biological resemblance to COVID-19, that is, that have common related genes with COVID-19.

|disease_cui|disease_name|
|:-:|:-:|
|UMLS CUIs identifying diseases (dbc)|Names of the diseases|

- **diseases_pheno_covid.tsv**: (dpc) diseases that have a phenotypical resemblance to COVID-19, that is, that have common related symptoms with COVID-19.

|disease_name|
|:-:|
|Names of the diseases (dpc)|

- **genes_dpc.tsv**:  genes related to diseases dpc and that are associated to targets and drugs potentially repurposable for COVID-19.

|gene_id|gene_symbol|gene_name|
|:-:|:-:|:-:|
|NCBI identifiers of genes|Symbols of the genes|Complete name of the genes|

- **targets_gc.tsv**: targets related to COVID associated genes, and that are also related to drugs potentially repurposable for COVID-19. 

|chembl_id|uniprot_id|
|:-:|:-:|
|Targets identified by CHEMBL identifiers|Targets identified by UniProt accession numbers|

- **targets_dpc.tsv**: targets related to dpc associated genes, that are also related to drugs potentially repurposable for COVID-19.

|chembl_id|uniprot_id|
|:-:|:-:|
|Targets identified by CHEMBL identifiers|Targets identified by UniProt accession numbers|




## results

Files with lists of drugs derived from the different paths of information.

- **drugs_allpaths.tsv**: drugs in all paths with the list of related targets (represented with the gene symbol).

|drug_id|drug_name|covid_symptoms_path1|dpc_path2|dpc_genes_path3|dbc_path4|covid_genes_path5|
|:-:|:-:|:-:|:-:|:-:|:-:|:-:|
|Drug CHEMBL identifier|Drug name|COVID-19 symptom(s) to which the drug is indicated for|Disease(s) (dpc) phenotypically similar to COVID-19 related to the drug [Number of shared symptoms between COVID-19 and the disease]|Targets (represented with NCBI gene symbols) related to diseases (dbc) that are associated to the drug [Number of diseases (dpc) phenotypically similar to COVID-19 that are related to the target]|Diseases (dbc) biologically similar to COVID-19 related to the drug [Number of shared genes between COVID-19 and the disease]|Target(s) (represented with NCBI gene symbols) related to COVID-19 associated to the drug|

- **drugs_path1.tsv**: list of drugs derived from Path 1. 

|drug_id|drug_name|
|:-:|:-:|
|Drug CHEMBL identifier|Drug name|

- **drugs_path2.tsv**: list of drugs derived from Path 2.

|drug_id|drug_name|
|:-:|:-:|
|Drug CHEMBL identifier|Drug name|

- **drugs_path3.tsv**: list of drugs derived from Path 3. 

|drug_id|drug_name|
|:-:|:-:|
|Drug CHEMBL identifier|Drug name|

- **drugs_path4.tsv**: list of drugs derived from Path 4. 

|drug_id|drug_name|
|:-:|:-:|
|Drug CHEMBL identifier|Drug name|

- **drugs_path5.tsv**: list of drugs derived from Path 5. 

|drug_id|drug_name|
|:-:|:-:|
|Drug CHEMBL identifier|Drug name|


## paths-pipeline.svg
Graphical representation of the different paths of information followed.